all.Enfsm<-function(){
     cat("\n")
     note_for_Enfsm_input()
     cat("\n")
     note_for_close_window()
     EnfSMMpar<-data.frame(parameter=c("Gender","bw (kg)","D (mg)","tau (hr)"),value=c(0))
     EnfSMMpar<-edit(EnfSMMpar)
##     EnfSMMpar<-zcheck(EnfSMMpar)
     cat("\n")
     note_for_Enfsm_conc_input()
     cat("\n")
     note_for_close_window()
     EnfSMpar<-data.frame(ts=c(0),conc=c(0))
     EnfSMpar<-edit(EnfSMpar)
##     EnfSMpar<-mscheck(EnfSMpar)
     cat("\n")
     Enf.sm(length(EnfSMpar$ts),EnfSMpar$conc,EnfSMpar$ts,EnfSMMpar[4,2],EnfSMMpar[3,2],EnfSMMpar[2,2],EnfSMMpar[1,2])
     note_for_convergence_plots()
     convergence_plots_sep()
     note_for_Enfsm_output()
     show(samplesStats("*"))
     cat("\n") 
     C<-pocpr(samplesStats("ka"),EnfSMMpar[3,2],EnfSMMpar[4,2],EnfSMMpar[4,2])
     sim<-matrix(C[1 ,1])
     coutput<-data.frame(sim)
     colnames(coutput)<-list("Ctss_pr (mg/L)")
     show(coutput)    
     cat("\n") 
     Enf.more()
}